<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllProduct Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Category;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;

class GetAllCategoryIds extends \Magento\Backend\App\Action
{
    /**
     * @var \Magento\Backend\Model\View\Result\Forward
     */
    protected $_filter;
    protected $_resultForwardFactory;
    protected $_json;


    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     */
    public function __construct(
        Filter $filter,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Catalog\Model\Category $categoryModel,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
    ) {
        parent::__construct($context);
        $this->_filter = $filter;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_categoryModel = $categoryModel;
        $this->_messageManager = $messageManager;
        $this->_resultForwardFactory = $resultForwardFactory;
        $this->_json = $jsonHelper;

    }


    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if (isset($token) && $token != null) {
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody(0);
        } else {
            $storeId = (int) $this->getRequest()->getParam('store', 0);
            $exportIds = [];
            $helper = $this->_connection;
            $collection = $this->_categoryModel->getCollection()
                                        ->addAttributeToFilter('level', ['neq' => 0], 'is_active', '1')
                                        ->addAttributeToSelect('entity_id');

        $exportIds = $collection->getAllIds();
       
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody($this->_json->jsonEncode($exportIds));
        }
    }
}
