<?php
/**
 * Webkul MarketingCloud Magento Connector SyncAllCustomer Controller
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */
namespace Webkul\MarketingCloudMagentoConnector\Controller\Adminhtml\Customer;

use Magento\Backend\App\Action;
use Magento\Ui\Component\MassAction\Filter;
use Magento\Framework\Controller\ResultFactory;
use Magento\Customer\Model\ResourceModel\Customer\CollectionFactory;

class GetAllCustomerIds extends \Magento\Backend\App\Action
{
    /**
     * @param Action\Context $context
     * @param Filter $filter
     * @param CollectionFactory $collectionFactory
     */
    protected $_collectionFactory;
    protected $_filter;
    protected $_scopeConfig;
    protected $_customer;
    protected $_customerFactory;
    protected $_json;


    public function __construct(
        Filter $filter,
        CollectionFactory $collectionFactory,
        \Magento\Customer\Model\Customer $customers,
        \Magento\Backend\App\Action\Context $context,
        \Magento\Customer\Model\CustomerFactory $customerFactory,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Framework\Json\Helper\Data $jsonHelper,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
    ) {
        parent::__construct($context);
        $this->_filter = $filter;
        $this->_customers = $customers;
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_customerFactory = $customerFactory;
        $this->_collectionFactory = $collectionFactory;
        $this->_resultForwardFactory = $resultForwardFactory;
        $this->_json = $jsonHelper;
    }

    public function execute()
    {
        $helper = $this->_connection;
        $sessionToken = $this->_session->getMarketingToken();
        $token = $this->_scopeConfig->getValue('marketingcloud/general/mc_conn_token');
        $relToken = $helper->genarateToken();
        if (isset($token) && $token != null) {
            $sessionToken = $token;
        }
        if ($sessionToken != $relToken) {
            $resultRedirect = $this->resultRedirectFactory->create();
            $this->messageManager->addError(__("Licence Invalid, Kindly use correct licence key!!!"));
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody(0);
        } else {
            $storeId = (int) $this->getRequest()->getParam('store', 0);
            $limit = $this->_scopeConfig->getValue('marketingcloud/batch/mc_batch_customer') ?? '10';
            $exportIds = [];
            $helper = $this->_connection;
            $collection = $this->_customers->getCollection()->getAllIds();
            $this->getResponse()->setHeader('Content-type', 'application/json');
            $this->getResponse()->setBody($this->_json->jsonEncode($collection));
        }
    }
}
