<?php
/**
 * Webkul MarketingCloudMagentoConnector CategorySaveAfterObserver Observer Model
 *
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 *
 */
namespace Webkul\MarketingCloudMagentoConnector\Observer;

use Magento\Framework\UrlInterface;
use Magento\Framework\Event\Manager;
use Magento\Framework\Event\ObserverInterface;
use Magento\Catalog\Api\CategoryRepositoryInterface;
use Webkul\MarketingCloudMagentoConnector\Helper\Connection;

class CategorySaveAfterObserver implements ObserverInterface
{
    protected $_state;

    public function __construct(

        \Magento\Catalog\Model\Category $catalogModel,
        CategoryRepositoryInterface $categoryRepository,
        \Magento\Framework\App\RequestInterface $requestInterface,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\Framework\App\State $state
    ) {
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_catalogModel = $catalogModel;
        $this->_messageManager = $messageManager;
        $this->_requestInterface = $requestInterface;
        $this->_categoryRepository = $categoryRepository;
        $this->_state = $state;
    }

    /**
     * Category save after event handler
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $areaCode = $this->_state->getAreaCode();
        $category = $observer->getEvent()->getCategory();
        $category->save();
        $catId = $category->getId();
        $helper = $this->_connection;

        $_objectManager = \Magento\Framework\App\ObjectManager::getInstance();
        $category = $_objectManager->create('Magento\Catalog\Model\Category')->load($catId);

        $autoOrder = $this->_scopeConfig->getValue('marketingcloud/general/mc_autosync');
        if ($catId && $autoOrder == '1') {
            $res = $helper->getAutoSyncCategory($category);
            if($res && $res[0]){
                $message = "Category Successfully Exported In DataExtension!!!";
                if ($areaCode!='frontend') {
                    $this->_messageManager->addSuccess(__($message));
                }
            } else{
                $respMessage = $res[1];
                $error = "Error,  >> ".$respMessage;
                if ($areaCode!='frontend') {
                    $this->_messageManager->addError(__($error));
                }
            }
        }
    }
}
